Documentation
¶
Overview ¶
Package store holds everything that has to do with persistence and manages stored data.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetActorExistenceChecker ¶
func GetActorExistenceChecker() id.ActorExistenceChecker
GetActorExistenceChecker returns the implementation to use for ActorExistenceChecker
func InitializeDatabase ¶
func InitializeDatabase()
InitializeDatabase initializes the database connection and makes sure the database schema is up to date
Types ¶
type Cases ¶
type Cases interface {
handler.TestCaseLister
middleware.TestCaseStore
id.TestExistenceChecker
handler.TestCaseAdder
handler.TestCaseRenamer
handler.TestCaseDeleter
}
Cases defines the interfaces a store for test cases needs to fulfill
type Groups ¶
type Groups interface {
handler.GroupLister
middleware.GroupRetriever
handler.GroupAdder
}
Groups defines the interfaces a store for groups needs to fulfill
type Projects ¶
type Projects interface {
ListForOwner(id.ActorID) ([]*project.Project, error)
ListForMember(id.ActorID) ([]*project.Project, error)
ListForActor(id.ActorID) ([]*project.Project, error)
ListAll() ([]*project.Project, error)
ListPublic() ([]*project.Project, error)
ListInternal() ([]*project.Project, error)
ListPrivate(id.ActorID) ([]*project.Project, error)
middleware.ProjectStore
id.ProjectExistenceChecker
handler.ProjectAdder
handler.ProjectDeleter
}
Projects defines the interfaces a store for projects needs to fulfill
type Protocols ¶ added in v1.1.0
type Protocols interface {
// AddCaseProtocol adds the given protocol to the store
AddCaseProtocol(r *test.CaseExecutionProtocol, testCaseVersion test.CaseVersion) (err error)
// AddSequenceProtocol adds the given protocol to the store
AddSequenceProtocol(r *test.SequenceExecutionProtocol, testSequenceVersion test.SequenceVersion) (err error)
// GetCaseExecutionProtocols gets the protocols for the testcase with given id,
// which is part of the project with given id.
GetCaseExecutionProtocols(testcaseID id.TestID) ([]test.CaseExecutionProtocol, error)
// GetCaseExecutionProtocols gets the protocols for all testcases of the project with given id.
GetCaseExecutionProtocolsForProject(project id.ProjectID) ([]test.CaseExecutionProtocol, error)
// GetCaseExecutionProtocol gets the protocol with the given id for the testcase with given id,
// which is part of the project with given id.
GetCaseExecutionProtocol(protocolID id.ProtocolID) (test.CaseExecutionProtocol, error)
// GetSequenceExecutionProtocols gets the protocols for the testsequence with given id,
// which is part of the project with given id.
GetSequenceExecutionProtocols(sequenceID id.TestID) ([]test.SequenceExecutionProtocol, error)
//GetSequenceExecutionProtocolsForProject gets the protocols for all test sequences of the project with given id.
GetSequenceExecutionProtocolsForProject(pID id.ProjectID) ([]test.SequenceExecutionProtocol, error)
// GetSequenceExecutionProtocol gets the protocol with the given id for the testsequence with given id,
// which is part of the project with given id.
GetSequenceExecutionProtocol(protocolID id.ProtocolID) (test.SequenceExecutionProtocol, error)
// GetTestVersionProtocols gets the protocols for the testVersion with given id
GetTestVersionProtocols(testVersionID id.TestVersionID) ([]id.ProtocolID, error)
}
func GetProtocolStore ¶ added in v1.1.0
func GetProtocolStore() Protocols
GetProtocolStore returns a store for protocols
type Sequences ¶
type Sequences interface {
handler.TestSequenceLister
middleware.TestSequenceStore
id.TestExistenceChecker
handler.TestSequenceAdder
handler.TestSequenceRenamer
handler.TestSequenceDeleter
}
Sequences defines the interfaces a store for test sequences needs to fulfill
func GetSequenceStore ¶
func GetSequenceStore() Sequences
GetSequenceStore returns a store for test sequences
type TODOs ¶ added in v1.4.0
type TODOs interface {
handler.TODOListAdder
handler.TODOListGetter
}
TODOs defines the interfaces a store for todos needs to fulfill
func GetTodoStore ¶ added in v1.4.0
func GetTodoStore() TODOs
GetTodoStore returns a store for TODOs
type Users ¶
type Users interface {
handler.UserLister
creation.RegisterServer
usersession.Auth
}
Users defines the interfaces a store for users needs to fulfill
Source Files
¶
- case_labels_sql.go
- case_sql.go
- case_version_sql.go
- case_version_sut_variant_sql.go
- case_version_sut_version_sql.go
- case_version_tester_sql.go
- common_sql.go
- doc.go
- group_sql.go
- interface.go
- owner_sql.go
- preconditions_sql.go
- project_labels_sql.go
- project_member_sql.go
- project_role_sql.go
- project_sql.go
- protocol_sql.go
- sequence_labels_sql.go
- sequence_sql.go
- sequence_version_case_sql.go
- sequence_version_sql.go
- sequence_version_tester_sql.go
- step_sql.go
- sut_variant_sql.go
- sut_version_sql.go
- todo_sql.go
- user_sql.go