Documentation
¶
Overview ¶
Package store holds everything that has to do with persistence and manages stored data.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetActorExistenceChecker ¶
func GetActorExistenceChecker() id.ActorExistenceChecker
GetActorExistenceChecker returns the implementation to use for ActorExistenceChecker
Types ¶
type Cases ¶
type Cases interface {
handler.TestCaseLister
middleware.TestCaseStore
id.TestExistenceChecker
handler.TestCaseAdder
handler.TestCaseRenamer
handler.TestCaseDeleter
}
Cases defines the interfaces a store for test cases needs to fulfill
type Groups ¶
type Groups interface {
handler.GroupLister
middleware.GroupRetriever
handler.GroupAdder
}
Groups defines the interfaces a store for groups needs to fulfill
type Projects ¶
type Projects interface {
List(string) ([]*project.Project, error)
ListAll() ([]*project.Project, error)
middleware.ProjectStore
id.ProjectExistenceChecker
handler.ProjectAdder
handler.ProjectDeleter
}
Projects defines the interfaces a store for projects needs to fulfill
type Sequences ¶
type Sequences interface {
handler.TestSequenceLister
middleware.TestSequenceStore
id.TestExistenceChecker
handler.TestSequenceAdder
handler.TestSequenceRenamer
handler.TestSequenceDeleter
}
Sequences defines the interfaces a store for test sequences needs to fulfill
func GetSequenceStore ¶
func GetSequenceStore() Sequences
GetSequenceStore returns a store for test sequences
type Users ¶
type Users interface {
handler.UserLister
handler.UserServer
handler.UserAuth
}
Users defines the interfaces a store for users needs to fulfill
Source Files
¶
Click to show internal directories.
Click to hide internal directories.